Module handler

Module handler 

Extractors for middleware functions

Structs

Next
Represents the Future that wraps the next middleware in the chain, that will be called by await with the current HttpContext

Traits

MapOkHandler
Describes a generic [map_ok] middleware handler that could take 0 or N parameters and HttpResponse
MiddlewareHandler
Describes a generic middleware handler that could take 0 or N parameters and Next middleware
TapReqHandler
Describes a generic [tap_req] middleware handler that could take 0 or N parameters and HttpRequestMut