Extractors for middleware functions
Structs
- Next
- Represents the
Futurethat wraps the next middleware in the chain, that will be called byawaitwith the currentHttpContext
Traits
- MapOk
Handler - Describes a generic [
map_ok] middleware handler that could take 0 or N parameters andHttpResponse - Middleware
Handler - Describes a generic middleware handler that could take 0 or N parameters and
Nextmiddleware - TapReq
Handler - Describes a generic [
tap_req] middleware handler that could take 0 or N parameters andHttpRequestMut